bayespy.inference.vmp.nodes.constant.Constant.get_mask
======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.get_mask